==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/s3_bucket_object_lock_configuration/S3BucketObjectLockConfigurationRuleA.java <==
package com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.411Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.s3BucketObjectLockConfiguration.S3BucketObjectLockConfigurationRuleA")
@software.amazon.jsii.Jsii.Proxy(S3BucketObjectLockConfigurationRuleA.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface S3BucketObjectLockConfigurationRuleA extends software.amazon.jsii.JsiiSerializable {

    /**
     * default_retention block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object_lock_configuration#default_retention S3BucketObjectLockConfigurationA#default_retention}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA getDefaultRetention();

    /**
     * @return a {@link Builder} of {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<S3BucketObjectLockConfigurationRuleA> {
        com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention;

        /**
         * Sets the value of {@link S3BucketObjectLockConfigurationRuleA#getDefaultRetention}
         * @param defaultRetention default_retention block. This parameter is required.
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object_lock_configuration#default_retention S3BucketObjectLockConfigurationA#default_retention}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultRetention(com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention) {
            this.defaultRetention = defaultRetention;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3BucketObjectLockConfigurationRuleA}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public S3BucketObjectLockConfigurationRuleA build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3BucketObjectLockConfigurationRuleA {
        private final com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.defaultRetention = software.amazon.jsii.Kernel.get(this, "defaultRetention", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.defaultRetention = java.util.Objects.requireNonNull(builder.defaultRetention, "defaultRetention is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA getDefaultRetention() {
            return this.defaultRetention;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("defaultRetention", om.valueToTree(this.getDefaultRetention()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.s3BucketObjectLockConfiguration.S3BucketObjectLockConfigurationRuleA"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3BucketObjectLockConfigurationRuleA.Jsii$Proxy that = (S3BucketObjectLockConfigurationRuleA.Jsii$Proxy) o;

            return this.defaultRetention.equals(that.defaultRetention);
        }

        @Override
        public final int hashCode() {
            int result = this.defaultRetention.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/s3_bucket_object_lock_configuration/S3BucketObjectLockConfigurationRuleA.java <==
package com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.481Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.s3BucketObjectLockConfiguration.S3BucketObjectLockConfigurationRuleA")
@software.amazon.jsii.Jsii.Proxy(S3BucketObjectLockConfigurationRuleA.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface S3BucketObjectLockConfigurationRuleA extends software.amazon.jsii.JsiiSerializable {

    /**
     * default_retention block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_object_lock_configuration#default_retention S3BucketObjectLockConfigurationA#default_retention}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA getDefaultRetention();

    /**
     * @return a {@link Builder} of {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<S3BucketObjectLockConfigurationRuleA> {
        com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention;

        /**
         * Sets the value of {@link S3BucketObjectLockConfigurationRuleA#getDefaultRetention}
         * @param defaultRetention default_retention block. This parameter is required.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/s3_bucket_object_lock_configuration#default_retention S3BucketObjectLockConfigurationA#default_retention}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultRetention(com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention) {
            this.defaultRetention = defaultRetention;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3BucketObjectLockConfigurationRuleA}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public S3BucketObjectLockConfigurationRuleA build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link S3BucketObjectLockConfigurationRuleA}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3BucketObjectLockConfigurationRuleA {
        private final com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA defaultRetention;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.defaultRetention = software.amazon.jsii.Kernel.get(this, "defaultRetention", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.defaultRetention = java.util.Objects.requireNonNull(builder.defaultRetention, "defaultRetention is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.s3_bucket_object_lock_configuration.S3BucketObjectLockConfigurationRuleDefaultRetentionA getDefaultRetention() {
            return this.defaultRetention;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("defaultRetention", om.valueToTree(this.getDefaultRetention()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.s3BucketObjectLockConfiguration.S3BucketObjectLockConfigurationRuleA"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3BucketObjectLockConfigurationRuleA.Jsii$Proxy that = (S3BucketObjectLockConfigurationRuleA.Jsii$Proxy) o;

            return this.defaultRetention.equals(that.defaultRetention);
        }

        @Override
        public final int hashCode() {
            int result = this.defaultRetention.hashCode();
            return result;
        }
    }
}
